@@ -5,7 +5,8 @@
 import zc.buildout.easy_install
 
 
-DEFAULT_ARGUMENTS = "'src', 'bin/test', '-cv'"
+DEFAULT_CMD_LINE = "-e py -e zcml -e pt -e txt src bin/test -cv"
+DEFAULT_ARGUMENTS = "'" + "', '".join(DEFAULT_CMD_LINE.split()) + "'"
 
 
 class Recipe(object):
@@ -20,6 +21,8 @@ class Recipe(object):
         self.index = buildout['buildout'].get('index')
         self.newest = buildout['buildout'].get('newest') == 'true'
         self.arguments = self.options.get('arguments', DEFAULT_ARGUMENTS)
+        name = self.options.get('name', 'callonchange')
+        self.scripts = {'callonchange': name}
 
     def install(self):
         distributions = ['icemac.callonchange']
@@ -36,6 +39,7 @@ class Recipe(object):
             ws,
             self.executable,
             self.bin_directory,
+            scripts=self.scripts,
             arguments=self.arguments,
             )
 
